@@ -5,11 +5,11 @@
 #' @param emp.r empirically observed correlation
 #' @param hypo.r expected correlation
 #' @param n sample size the observed correlation is based on
-#' @return Fisher's z-values, corresponding p-values, and Cohen's q
+#' @return Fisher's z-values, corresponding p-values, adjusted alpha level, and Cohen's q
 #' @examples cor.1 <- diffcor.one(.76, .70, 271)
 #' @export
 
-diffcor.one <- function(emp.r, hypo.r, n, cor.names = NULL, alternative = c("one.sided", "two.sided")){
+diffcor.one <- function(emp.r, hypo.r, n, cor.names = NULL, alternative = c("one.sided", "two.sided"), bonferroni = TRUE, digit = 3, alpha = .05){
   fisher.emp <- atanh(emp.r);
   exp.r <- atanh(hypo.r)+(hypo.r/((2*n)-1));
   Var.z <- (n-3);
@@ -20,12 +20,21 @@ diffcor.one <- function(emp.r, hypo.r, n, cor.names = NULL, alternative = c("one
   alternative <- match.arg(alternative);
   tside <- switch(alternative, one.sided = 1, two.sided = 2)
   if (tside == 1)
-    p <- format(round(1-pnorm(abs(diff.z.one)), 4), scientific = F);
+    p <- format(round(1-pnorm(abs(diff.z.one)), digit), scientific = F);
   if (tside == 2)
-    p <- format(round(2*pnorm(-abs(diff.z.one)), 4), scientific = F);
+    p <- format(round(2*pnorm(-abs(diff.z.one)), digit), scientific = F);
 
-  res.one <- data.frame(diff.z.one, p, Cohen.q.one);
-  colnames(res.one) <- c("Fisher z", "p value", "Cohen's q");
+  alpha.Bonferroni <- round(alpha/length(fisher.emp), digit);
+  significant <- p < alpha.Bonferroni;
+
+  if(bonferroni == TRUE)
+    res.one <- data.frame("Fisher_z" = diff.z.one, "p" = p,
+                          "alpha_Bonferroni" = alpha.Bonferroni,
+                          "Bonferroni_significant" = significant,
+                          "Cohen_q" = Cohen.q.one);
+  if(bonferroni == FALSE)
+    res.one <- data.frame("Fisher_z" = diff.z.one, "p" = p,
+                          "Cohen_q" = Cohen.q.one);
   row.names(res.one) <- cor.names;
 
   return(res.one)}
@@ -41,7 +50,7 @@ diffcor.one <- function(emp.r, hypo.r, n, cor.names = NULL, alternative = c("one
 #' @examples diffcor.two(r1 = .76, r2 = .70, n1 = 271, n2 = 323)
 #' @export
 
-diffcor.two <- function(r1, r2, n1, n2, cor.names = NULL, alternative = c("one.sided", "two.sided")){
+diffcor.two <- function(r1, r2, n1, n2, cor.names = NULL, alternative = c("one.sided", "two.sided"), bonferroni = TRUE, digit = 3, alpha = .05){
   fisher1 <- atanh(r1); fisher2 <- atanh(r2);
   Var1 <- 1/(n1-3); Var2 <- 1/(n2-3); SE <- sqrt((Var1+Var2));
 
@@ -51,17 +60,25 @@ diffcor.two <- function(r1, r2, n1, n2, cor.names = NULL, alternative = c("one.s
   alternative <- match.arg(alternative);
   tside <- switch(alternative, one.sided = 1, two.sided = 2)
   if (tside == 1)
-    p <- format(round(1-pnorm(abs(diff.z.two)), 4), scientific = F);
+    p <- format(round(1-pnorm(abs(diff.z.two)), digit), scientific = F);
   if (tside == 2)
-    p <- format(round(2*pnorm(-abs(diff.z.two)), 4), scientific = F);
+    p <- format(round(2*pnorm(-abs(diff.z.two)), digit), scientific = F);
 
+  alpha.Bonferroni <- round(alpha/length(fisher1), digit);
+  significant <- p < alpha.Bonferroni;
 
-  res.two <- data.frame(diff.z.two, p, Cohen.q.two);
-  colnames(res.two) <- c("Fisher z", "p value", "Cohen's q");
-  row.names(res.two) <- cor.names
+  if(bonferroni == TRUE)
+    res.two <- data.frame("Fisher_z" = diff.z.two, "p" = p,
+                          "alpha_Bonferroni" = alpha.Bonferroni,
+                          "Bonferroni_significant" = significant,
+                          "Cohen_q" = Cohen.q.two);
+  if(bonferroni == FALSE)
+    res.two <- data.frame("Fisher_z" = diff.z.two, "p" = p,
+                          "Cohen_q" = Cohen.q.two);
+  row.names(res.two) <- cor.names;
 
   return(res.two)
-}
+  }
 
 #' Test concerning differences between two dependent correlations
 #'
@@ -74,7 +91,7 @@ diffcor.two <- function(r1, r2, n1, n2, cor.names = NULL, alternative = c("one.s
 #' @examples diffcor.dep(r12 = .76, r13 = .70, r23 = .50, n = 271)
 #' @export
 
-diffcor.dep <- function(r12, r13, r23, n, cor.names = NULL, alternative = c("one.sided", "two.sided")){
+diffcor.dep <- function(r12, r13, r23, n, cor.names = NULL, alternative = c("one.sided", "two.sided"), bonferroni = TRUE, digit = 3, alpha = .05){
   z12 <- atanh(r12); z13 <- atanh(r13); r1 <- (r12+r13)/2;
   Cov.dep.a <- 1/(1-r1^2)^2; Cov.dep.b <- r23*(1-2*r1^2); Cov.dep.c <- -.50*(r1^2); Cov.dep.d <- 1-(2*(r1^2))-r23^2;
   Cov.dep <- (Cov.dep.a*Cov.dep.b)+(Cov.dep.c*Cov.dep.d);
@@ -84,13 +101,19 @@ diffcor.dep <- function(r12, r13, r23, n, cor.names = NULL, alternative = c("one
   alternative <- match.arg(alternative);
   tside <- switch(alternative, one.sided = 1, two.sided = 2)
   if (tside == 1)
-    p <- format(round(1-pnorm(abs(diff.z.dep)), 4), scientific = F);
+    p <- format(round(1-pnorm(abs(diff.z.dep)), digit), scientific = F);
   if (tside == 2)
-    p <- format(round(2*pnorm(-abs(diff.z.dep)), 4), scientific = F);
+    p <- format(round(2*pnorm(-abs(diff.z.dep)), digit), scientific = F);
 
+  alpha.Bonferroni <- round(alpha/length(z12), digit);
+  significant <- p < alpha.Bonferroni;
 
-  res.dep <- data.frame(diff.z.dep, p);
-  colnames(res.dep) <- c("Fisher z", "p value");
-  row.names(res.dep) <- cor.names
+  if(bonferroni == TRUE)
+    res.dep <- data.frame("Fisher_z" = diff.z.dep, "p" = p,
+                          "alpha_Bonferroni" = alpha.Bonferroni,
+                          "Bonferroni_significant" = significant);
+  if(bonferroni == FALSE)
+    res.dep <- data.frame("Fisher_z" = diff.z.dep, "p" = p);
+  row.names(res.dep) <- cor.names;
   return(res.dep)
 }
